==> huaweicloudsdkdataartsstudio-3.1.68-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/update_work_space_user_or_group_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateWorkSpaceUserOrGroupRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workspace_id': 'str',
        'user_id': 'str',
        'body': 'ApigWorkspaceUserDto'
    }

    attribute_map = {
        'workspace_id': 'workspace_id',
        'user_id': 'user_id',
        'body': 'body'
    }

    def __init__(self, workspace_id=None, user_id=None, body=None):
        """UpdateWorkSpaceUserOrGroupRequest

        The model defined in huaweicloud sdk

        :param workspace_id: 工作空间id
        :type workspace_id: str
        :param user_id: 用户id
        :type user_id: str
        :param body: Body of the UpdateWorkSpaceUserOrGroupRequest
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.ApigWorkspaceUserDto`
        """
        
        

        self._workspace_id = None
        self._user_id = None
        self._body = None
        self.discriminator = None

        self.workspace_id = workspace_id
        self.user_id = user_id
        if body is not None:
            self.body = body

    @property
    def workspace_id(self):
        """Gets the workspace_id of this UpdateWorkSpaceUserOrGroupRequest.

        工作空间id

        :return: The workspace_id of this UpdateWorkSpaceUserOrGroupRequest.
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this UpdateWorkSpaceUserOrGroupRequest.

        工作空间id

        :param workspace_id: The workspace_id of this UpdateWorkSpaceUserOrGroupRequest.
        :type workspace_id: str
        """
        self._workspace_id = workspace_id

    @property
    def user_id(self):
        """Gets the user_id of this UpdateWorkSpaceUserOrGroupRequest.

        用户id

        :return: The user_id of this UpdateWorkSpaceUserOrGroupRequest.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UpdateWorkSpaceUserOrGroupRequest.

        用户id

        :param user_id: The user_id of this UpdateWorkSpaceUserOrGroupRequest.
        :type user_id: str
        """
        self._user_id = user_id

    @property
    def body(self):
        """Gets the body of this UpdateWorkSpaceUserOrGroupRequest.

        :return: The body of this UpdateWorkSpaceUserOrGroupRequest.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.ApigWorkspaceUserDto`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateWorkSpaceUserOrGroupRequest.

        :param body: The body of this UpdateWorkSpaceUserOrGroupRequest.
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.ApigWorkspaceUserDto`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateWorkSpaceUserOrGroupRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/update_work_space_user_or_group_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateWorkSpaceUserOrGroupRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workspace_id': 'str',
        'user_id': 'str',
        'body': 'ApigWorkspaceUserDto'
    }

    attribute_map = {
        'workspace_id': 'workspace_id',
        'user_id': 'user_id',
        'body': 'body'
    }

    def __init__(self, workspace_id=None, user_id=None, body=None):
        r"""UpdateWorkSpaceUserOrGroupRequest

        The model defined in huaweicloud sdk

        :param workspace_id: 工作空间id
        :type workspace_id: str
        :param user_id: 用户id
        :type user_id: str
        :param body: Body of the UpdateWorkSpaceUserOrGroupRequest
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.ApigWorkspaceUserDto`
        """
        
        

        self._workspace_id = None
        self._user_id = None
        self._body = None
        self.discriminator = None

        self.workspace_id = workspace_id
        self.user_id = user_id
        if body is not None:
            self.body = body

    @property
    def workspace_id(self):
        r"""Gets the workspace_id of this UpdateWorkSpaceUserOrGroupRequest.

        工作空间id

        :return: The workspace_id of this UpdateWorkSpaceUserOrGroupRequest.
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        r"""Sets the workspace_id of this UpdateWorkSpaceUserOrGroupRequest.

        工作空间id

        :param workspace_id: The workspace_id of this UpdateWorkSpaceUserOrGroupRequest.
        :type workspace_id: str
        """
        self._workspace_id = workspace_id

    @property
    def user_id(self):
        r"""Gets the user_id of this UpdateWorkSpaceUserOrGroupRequest.

        用户id

        :return: The user_id of this UpdateWorkSpaceUserOrGroupRequest.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        r"""Sets the user_id of this UpdateWorkSpaceUserOrGroupRequest.

        用户id

        :param user_id: The user_id of this UpdateWorkSpaceUserOrGroupRequest.
        :type user_id: str
        """
        self._user_id = user_id

    @property
    def body(self):
        r"""Gets the body of this UpdateWorkSpaceUserOrGroupRequest.

        :return: The body of this UpdateWorkSpaceUserOrGroupRequest.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.ApigWorkspaceUserDto`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateWorkSpaceUserOrGroupRequest.

        :param body: The body of this UpdateWorkSpaceUserOrGroupRequest.
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.ApigWorkspaceUserDto`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateWorkSpaceUserOrGroupRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
